@@ -4,6 +4,7 @@ import dataclasses
 import enum
 import fractions
 import importlib.resources
+import json
 from typing import ClassVar, Dict, NamedTuple, Union
 import warnings
 
@@ -97,34 +98,36 @@ class SteelMaterial():
         Raises
         ------
         ValueError
-            If multiple materials match the provided information. For example,
-            requesting an A500 steel also requires specifying a grade (A or B).
+            - If no materials are found.
+            - If multiple materials match the provided information. For example,
+              requesting an A500 steel also requires specifying a grade (A or
+              B).
         """
         name, grade = _check_deprecated_material(name, grade)
 
-        def normalize(input):
-            if pd.isna(input):
-                return slice(None)
-            else:
-                return str(input).casefold()
+        # Construct database query
+        query_name = str(name).casefold()
+        query_list = [f'name == {query_name!r}']
+        if grade is not None:
+            query_grade = str(grade).casefold()
+            query_list.append(f'grade == {query_grade!r}')
+        if application is not None:
+            query_application = str(application).casefold()
+            query_list.append(f'application == {query_application!r}')
+        query = ' & '.join(query_list)
 
-        material = cls._get_materials_db().loc[normalize(name),
-                                               normalize(grade),
-                                               normalize(application)]
+        # Lookup -- should get a DataFrame of length 1.
+        material = cls._get_materials_db().query(query)
+        if len(material) == 0:
+            raise ValueError('No materials found')
+        elif len(material) != 1:
+            raise ValueError(f'Multiple materials found:\n{material}')
 
-        # Lookup succeeds if we get a Series (exact indexes) or if we get a
-        # DataFrame of length 1 (one or more indexes were sliced, but still only
-        # one result returned).
-        if isinstance(material, pd.DataFrame):
-            if len(material) != 1:
-                raise ValueError('Multiple materials found: specify grade '
-                                 'and/or application to narrow search')
-            material = material.iloc[0]
-
-        name, grade, application = material.name
+        data = material.iloc[0]
+        name, grade, application = data.name
         display_grade = '' if pd.isna(grade) else f' Gr. {grade}'
         display_name = f'{name}{display_grade} ({application})'
-        return cls(display_name.title(), **material)
+        return cls(display_name.title(), **data)
 
     @classmethod
     def available_materials(cls):
@@ -153,7 +156,7 @@ def _check_deprecated_material(name, grade):
 
 
 def _load_materials_db(filename):
-    with importlib.resources.path('libtalley', filename) as p:
+    with importlib.resources.path(__package__, filename) as p:
         material_df = pd.read_csv(p, index_col=['name', 'grade', 'application'])
     material_df.sort_index(inplace=True)
     return material_df
@@ -318,7 +321,7 @@ class _ShapesResource():
     name: str
     units: Dict[str, str]
     filename: str
-    package: str = 'libtalley'
+    package: str = __package__
 
     _registry: ClassVar[Dict[str, _ShapesResource]] = {}
 
@@ -335,7 +338,7 @@ class _ShapesResource():
         return resource
 
     @classmethod
-    def register(cls, key, name, units, filename, package='libtalley'):
+    def register(cls, key, name, units, filename, package=__package__):
         if key in cls._registry:
             raise ValueError(f'resource with key {key!r} is already registered')
 
@@ -346,178 +349,18 @@ class _ShapesResource():
         return cls._registry[key]
 
 
-_ShapesResource.register('US',
-                         name='AISC Shapes Database v15.0 (US)',
-                         filename='aisc-shapes-database-v15-0-US.csv.bz2',
-                         units={
-                             'W': 'lbf/ft',
-                             'A': 'inch**2',
-                             'd': 'inch',
-                             'ddet': 'inch',
-                             'Ht': 'inch',
-                             'h': 'inch',
-                             'OD': 'inch',
-                             'bf': 'inch',
-                             'bfdet': 'inch',
-                             'B': 'inch',
-                             'b': 'inch',
-                             'ID': 'inch',
-                             'tw': 'inch',
-                             'twdet': 'inch',
-                             'twdet/2': 'inch',
-                             'tf': 'inch',
-                             'tfdet': 'inch',
-                             't': 'inch',
-                             'tnom': 'inch',
-                             'tdes': 'inch',
-                             'kdes': 'inch',
-                             'kdet': 'inch',
-                             'k1': 'inch',
-                             'x': 'inch',
-                             'y': 'inch',
-                             'eo': 'inch',
-                             'xp': 'inch',
-                             'yp': 'inch',
-                             'bf/2tf': 'dimensionless',
-                             'b/t': 'dimensionless',
-                             'b/tdes': 'dimensionless',
-                             'h/tw': 'dimensionless',
-                             'h/tdes': 'dimensionless',
-                             'D/t': 'dimensionless',
-                             'Ix': 'inch**4',
-                             'Zx': 'inch**3',
-                             'Sx': 'inch**3',
-                             'rx': 'inch',
-                             'Iy': 'inch**4',
-                             'Zy': 'inch**3',
-                             'Sy': 'inch**3',
-                             'ry': 'inch',
-                             'Iz': 'inch**4',
-                             'rz': 'inch',
-                             'Sz': 'inch**3',
-                             'J': 'inch**4',
-                             'Cw': 'inch**6',
-                             'C': 'inch**3',
-                             'Wno': 'inch**2',
-                             'Sw1': 'inch**4',
-                             'Sw2': 'inch**4',
-                             'Sw3': 'inch**4',
-                             'Qf': 'inch**3',
-                             'Qw': 'inch**3',
-                             'ro': 'inch',
-                             'H': 'dimensionless',
-                             'tan(α)': 'dimensionless',
-                             'Iw': 'inch**4',
-                             'zA': 'inch',
-                             'zB': 'inch',
-                             'zC': 'inch',
-                             'wA': 'inch',
-                             'wB': 'inch',
-                             'wC': 'inch',
-                             'SzA': 'inch**3',
-                             'SzB': 'inch**3',
-                             'SzC': 'inch**3',
-                             'SwA': 'inch**3',
-                             'SwB': 'inch**3',
-                             'SwC': 'inch**3',
-                             'rts': 'inch',
-                             'ho': 'inch',
-                             'PA': 'inch',
-                             'PA2': 'inch',
-                             'PB': 'inch',
-                             'PC': 'inch',
-                             'PD': 'inch',
-                             'T': 'inch',
-                             'WGi': 'inch',
-                             'WGo': 'inch',
-                         })
+def _register_resources():
+    s = importlib.resources.read_text(__package__, 'shapes-resources.json')
+    shapes_resources: Dict[str, dict] = json.loads(s)['shapes_resources']
+    for key, resource in shapes_resources.items():
+        _ShapesResource.register(key,
+                                 name=resource['name'],
+                                 filename=resource['filename'],
+                                 units=resource['units'],
+                                 package=resource.get('package', __package__))
 
-_ShapesResource.register('SI',
-                         name='AISC Shapes Database v15.0 (SI)',
-                         filename='aisc-shapes-database-v15-0-SI.csv.bz2',
-                         units={
-                             'W': 'kg/m',
-                             'A': 'mm**2',
-                             'd': 'mm',
-                             'ddet': 'mm',
-                             'Ht': 'mm',
-                             'h': 'mm',
-                             'OD': 'mm',
-                             'bf': 'mm',
-                             'bfdet': 'mm',
-                             'B': 'mm',
-                             'b': 'mm',
-                             'ID': 'mm',
-                             'tw': 'mm',
-                             'twdet': 'mm',
-                             'twdet/2': 'mm',
-                             'tf': 'mm',
-                             'tfdet': 'mm',
-                             't': 'mm',
-                             'tnom': 'mm',
-                             'tdes': 'mm',
-                             'kdes': 'mm',
-                             'kdet': 'mm',
-                             'k1': 'mm',
-                             'x': 'mm',
-                             'y': 'mm',
-                             'eo': 'mm',
-                             'xp': 'mm',
-                             'yp': 'mm',
-                             'bf/2tf': 'dimensionless',
-                             'b/t': 'dimensionless',
-                             'b/tdes': 'dimensionless',
-                             'h/tw': 'dimensionless',
-                             'h/tdes': 'dimensionless',
-                             'D/t': 'dimensionless',
-                             'Ix': '1e6*mm**4',
-                             'Zx': '1e3*mm**3',
-                             'Sx': '1e3*mm**3',
-                             'rx': 'mm',
-                             'Iy': '1e6*mm**4',
-                             'Zy': '1e3*mm**3',
-                             'Sy': '1e3*mm**3',
-                             'ry': 'mm',
-                             'Iz': '1e6*mm**4',
-                             'rz': 'mm',
-                             'Sz': '1e3*mm**3',
-                             'J': '1e3*mm**4',
-                             'Cw': '1e9*mm**6',
-                             'C': '1e3*mm**3',
-                             'Wno': 'mm**2',
-                             'Sw1': '1e6*mm**4',
-                             'Sw2': '1e6*mm**4',
-                             'Sw3': '1e6*mm**4',
-                             'Qf': '1e3*mm**3',
-                             'Qw': '1e3*mm**3',
-                             'ro': 'mm',
-                             'H': 'dimensionless',
-                             'tan(α)': 'dimensionless',
-                             'Iw': '1e6*mm**4',
-                             'zA': 'mm',
-                             'zB': 'mm',
-                             'zC': 'mm',
-                             'wA': 'mm',
-                             'wB': 'mm',
-                             'wC': 'mm',
-                             'SzA': '1e3*mm**3',
-                             'SzB': '1e3*mm**3',
-                             'SzC': '1e3*mm**3',
-                             'SwA': '1e3*mm**3',
-                             'SwB': '1e3*mm**3',
-                             'SwC': '1e3*mm**3',
-                             'rts': 'mm',
-                             'ho': 'mm',
-                             'PA': 'mm',
-                             'PA2': 'mm',
-                             'PB': 'mm',
-                             'PC': 'mm',
-                             'PD': 'mm',
-                             'T': 'mm',
-                             'WGi': 'mm',
-                             'WGo': 'mm',
-                         })
 
+_register_resources()
 shapes_US = ShapesTable.from_resource('US')
 shapes_SI = ShapesTable.from_resource('SI')
 
